==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/blocks/FlaxCropBlock.java <==
package xen42.peacefulitems.blocks;

import net.minecraft.class_1922;
import net.minecraft.class_1935;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2302;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2741;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import net.minecraft.class_3481;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_4970;
import net.minecraft.class_5819;
import xen42.peacefulitems.PeacefulModBlocks;
import xen42.peacefulitems.PeacefulModItems;

public class FlaxCropBlock extends class_2302 {

    public static final class_2758 AGE = class_2741.field_12550;

    private static final class_265[] AGE_TO_SHAPE = new class_265[] {
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 2.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 3.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 4.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 5.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 8.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 14.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 16.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 16.0D, 16.0D)
        };
 
    public FlaxCropBlock(class_4970.class_2251 settings) {
        super(settings);
    }

    @Override
    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        // Lets the top block keep existing
        class_2680 lv = world.method_8320(pos.method_10074());
        if (lv.method_26164(class_3481.field_29822) || lv.method_27852(class_2246.field_10362)) {
            return true;
        }
        else {
            return false;
        }
    }

    // Stop random ticking if its the second highest age but has a top block
	@Override
	protected void method_9514(class_2680 state, class_3218 world, class_2338 pos, class_5819 random) {
        if (state.method_11654(field_10835) == this.method_9827() - 1 && world.method_8320(pos.method_10084()).method_27852(this)) {
            return;
        }
		super.method_9514(state, world, pos, random);
        if (state.method_11654(field_10835) >= this.method_9827() - 1) {
            if (world.method_8320(pos.method_10084()).method_26215()) {
                world.method_8501(pos.method_10084(), PeacefulModBlocks.FLAX_CROP.method_9564().method_11657(field_10835, this.method_9827()));
            }
            world.method_8652(pos, this.method_9828(this.method_9827() - 1), class_2248.field_31028);
        }
	}

    @Override
    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (!state.method_26184(world, pos) && !world.method_8320(pos.method_10074()).method_27852(this)) {
            return class_2246.field_10124.method_9564();
        }
        return state;
    }

    @Override
    protected class_2758 method_9824() {
        return field_10835;
    }

    @Override
    public int method_9827() {
        return 7;
    }
 
    @Override
    protected class_1935 method_9832() {
        return PeacefulModItems.FLAX;
    }

    @Override
    public void method_9826(class_1937 world, class_2338 pos, class_2680 state) {
        int j;
        int i = this.method_9829(state) + this.method_9831(world);
        if (i > (j = this.method_9827() - 1)) {
            i = j;
            if (world.method_8320(pos.method_10084()).method_26215()) {
                world.method_8501(pos.method_10084(), PeacefulModBlocks.FLAX_CROP.method_9564().method_11657(field_10835, this.method_9827()));
            }
        }
        world.method_8652(pos, this.method_9828(i), class_2248.field_31028);
    }

    @Override
    public boolean method_9651(class_4538 world, class_2338 pos, class_2680 state) {
        return !this.method_9825(state) && !world.method_8320(pos.method_10084()).method_27852(this);
    }
 
    @Override
    protected class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return AGE_TO_SHAPE[method_9829(state)];
    }
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/blocks/FlaxCropBlock.java <==
package xen42.peacefulitems.blocks;

import net.minecraft.class_10225;
import net.minecraft.class_1922;
import net.minecraft.class_1935;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2302;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2741;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import net.minecraft.class_3481;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_4970;
import net.minecraft.class_5819;
import xen42.peacefulitems.PeacefulModBlocks;
import xen42.peacefulitems.PeacefulModItems;

public class FlaxCropBlock extends class_2302 {

    public static final class_2758 AGE = class_2741.field_12550;

    private static final class_265[] AGE_TO_SHAPE = new class_265[] {
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 2.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 3.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 4.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 5.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 8.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 14.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 16.0D, 16.0D),
            class_2248.method_9541(0.0D, 0.0D, 0.0D, 16.0D, 16.0D, 16.0D)
        };
 
    public FlaxCropBlock(class_4970.class_2251 settings) {
        super(settings);
    }

    @Override
    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        // Lets the top block keep existing
        class_2680 lv = world.method_8320(pos.method_10074());
        if (lv.method_26164(class_3481.field_29822) || lv.method_27852(class_2246.field_10362)) {
            return true;
        }
        else {
            return false;
        }
    }

    // Stop random ticking if its the second highest age but has a top block
	@Override
	protected void method_9514(class_2680 state, class_3218 world, class_2338 pos, class_5819 random) {
        if (state.method_11654(field_10835) == this.method_9827() - 1 && world.method_8320(pos.method_10084()).method_27852(this)) {
            return;
        }
		super.method_9514(state, world, pos, random);
        if (state.method_11654(field_10835) >= this.method_9827() - 1) {
            if (world.method_8320(pos.method_10084()).method_26215()) {
                world.method_8501(pos.method_10084(), PeacefulModBlocks.FLAX_CROP.method_9564().method_11657(field_10835, this.method_9827()));
            }
            world.method_8652(pos, this.method_9828(this.method_9827() - 1), class_2248.field_31028);
        }
	}

    @Override
    public class_2680 method_9559(class_2680 state, class_4538 world, class_10225 view, class_2338 pos, class_2350 direction, class_2338 neighborPos, class_2680 neighborState, class_5819 random) {
        if (!state.method_26184(world, pos) && !world.method_8320(pos.method_10074()).method_27852(this)) {
            return class_2246.field_10124.method_9564();
        }
        return state;
    }

    @Override
    protected class_2758 method_9824() {
        return field_10835;
    }

    @Override
    public int method_9827() {
        return 7;
    }
 
    @Override
    protected class_1935 method_9832() {
        return PeacefulModItems.FLAX;
    }

    @Override
    public void method_9826(class_1937 world, class_2338 pos, class_2680 state) {
        int j;
        int i = this.method_9829(state) + this.method_9831(world);
        if (i > (j = this.method_9827() - 1)) {
            i = j;
            if (world.method_8320(pos.method_10084()).method_26215()) {
                world.method_8501(pos.method_10084(), PeacefulModBlocks.FLAX_CROP.method_9564().method_11657(field_10835, this.method_9827()));
            }
        }
        world.method_8652(pos, this.method_9828(i), class_2248.field_31028);
    }

    @Override
    public boolean method_9651(class_4538 world, class_2338 pos, class_2680 state) {
        return !this.method_9825(state) && !world.method_8320(pos.method_10084()).method_27852(this);
    }
 
    @Override
    protected class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return AGE_TO_SHAPE[method_9829(state)];
    }
}
